==> selenium-devtools-v117-4.14.0-sources.jar: org/openqa/selenium/devtools/v117/css/model/CSSPositionFallbackRule.java <==
package org.openqa.selenium.devtools.v117.css.model;

import org.openqa.selenium.Beta;
import org.openqa.selenium.json.JsonInput;

/**
 * CSS position-fallback rule representation.
 */
public class CSSPositionFallbackRule {

    private final org.openqa.selenium.devtools.v117.css.model.Value name;

    private final java.util.List<org.openqa.selenium.devtools.v117.css.model.CSSTryRule> tryRules;

    public CSSPositionFallbackRule(org.openqa.selenium.devtools.v117.css.model.Value name, java.util.List<org.openqa.selenium.devtools.v117.css.model.CSSTryRule> tryRules) {
        this.name = java.util.Objects.requireNonNull(name, "name is required");
        this.tryRules = java.util.Objects.requireNonNull(tryRules, "tryRules is required");
    }

    public org.openqa.selenium.devtools.v117.css.model.Value getName() {
        return name;
    }

    /**
     * List of keyframes.
     */
    public java.util.List<org.openqa.selenium.devtools.v117.css.model.CSSTryRule> getTryRules() {
        return tryRules;
    }

    private static CSSPositionFallbackRule fromJson(JsonInput input) {
        org.openqa.selenium.devtools.v117.css.model.Value name = null;
        java.util.List<org.openqa.selenium.devtools.v117.css.model.CSSTryRule> tryRules = null;
        input.beginObject();
        while (input.hasNext()) {
            switch(input.nextName()) {
                case "name":
                    name = input.read(org.openqa.selenium.devtools.v117.css.model.Value.class);
                    break;
                case "tryRules":
                    tryRules = input.read(new com.google.common.reflect.TypeToken<java.util.List<org.openqa.selenium.devtools.v117.css.model.CSSTryRule>>() {
                    }.getType());
                    break;
                default:
                    input.skipValue();
                    break;
            }
        }
        input.endObject();
        return new CSSPositionFallbackRule(name, tryRules);
    }
}

==> selenium-devtools-v117-4.15.0-sources.jar: org/openqa/selenium/devtools/v117/css/model/CSSPositionFallbackRule.java <==
package org.openqa.selenium.devtools.v117.css.model;

import org.openqa.selenium.Beta;
import org.openqa.selenium.json.JsonInput;

/**
 * CSS position-fallback rule representation.
 */
public class CSSPositionFallbackRule {

    private final org.openqa.selenium.devtools.v117.css.model.Value name;

    private final java.util.List<org.openqa.selenium.devtools.v117.css.model.CSSTryRule> tryRules;

    public CSSPositionFallbackRule(org.openqa.selenium.devtools.v117.css.model.Value name, java.util.List<org.openqa.selenium.devtools.v117.css.model.CSSTryRule> tryRules) {
        this.name = java.util.Objects.requireNonNull(name, "name is required");
        this.tryRules = java.util.Objects.requireNonNull(tryRules, "tryRules is required");
    }

    public org.openqa.selenium.devtools.v117.css.model.Value getName() {
        return name;
    }

    /**
     * List of keyframes.
     */
    public java.util.List<org.openqa.selenium.devtools.v117.css.model.CSSTryRule> getTryRules() {
        return tryRules;
    }

    private static CSSPositionFallbackRule fromJson(JsonInput input) {
        org.openqa.selenium.devtools.v117.css.model.Value name = null;
        java.util.List<org.openqa.selenium.devtools.v117.css.model.CSSTryRule> tryRules = null;
        input.beginObject();
        while (input.hasNext()) {
            switch(input.nextName()) {
                case "name":
                    name = input.read(org.openqa.selenium.devtools.v117.css.model.Value.class);
                    break;
                case "tryRules":
                    tryRules = input.readArray(org.openqa.selenium.devtools.v117.css.model.CSSTryRule.class);
                    break;
                default:
                    input.skipValue();
                    break;
            }
        }
        input.endObject();
        return new CSSPositionFallbackRule(name, tryRules);
    }
}
